@@ -59,6 +59,26 @@ var InteractiveTableModel = widgets.DOMWidgetModel.extend({
 
 // Custom View. Renders the widget model.
 var InteractiveTableView = widgets.DOMWidgetView.extend({
+    createElements: function(data, td) {
+      var self = this;
+      var render = self.model.get('render_html');
+      if(render){
+        console.log(data)
+        let parser = new DOMParser();
+        let doc = parser.parseFromString(data, 'text/html');
+        let collection = doc.getElementsByTagName('body');
+        let nodes = collection[0].childNodes;
+        nodes.forEach(element => {
+          console.log(element)
+          td.appendChild(element);
+        })
+        
+        return td
+      }
+      td.appendChild(document.createTextNode(data))
+      return td;
+      
+    },
     // Defines how the widget gets rendered into the DOM
     render: function() {
       var self = this;
@@ -131,9 +151,9 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
           }else if(temp_value.length > self.model.get("text_limit")){
             self.dropdown = true;
             self.cols.push("over_length")
-            td.appendChild(document.createTextNode(temp_value));
+            td = self.createElements(temp_value.replace('&lt;','<').replace('&gt;', '>'), td);
           }else{
-            td.appendChild(document.createTextNode(temp_value));
+            td = self.createElements(temp_value, td);
           }
 
           // Storing the columns in the cols variable.
@@ -147,7 +167,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
         // Adding the openning child column at beginning.
         if(self.dropdown){
           var td = document.createElement('td');
-          td.appendChild(document.createTextNode("+"));
+          td = self.createElements("+", td);
           td.className = "show_details";
 
           $(tr).prepend(td)
@@ -170,7 +190,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
         if(value != "group" && value != "over_length"){
           self.columns.push(value)
           append_first = true;
-          td.appendChild(document.createTextNode(value))
+          td = self.createElements(value.replace('&lt;','<').replace('&gt;', '>'), td);
           tr.appendChild(td)
         }
         else{
@@ -240,8 +260,8 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
                 let td_col = document.createElement('td');
                 let td_value = document.createElement('td');
                 
-                td_col.appendChild(document.createTextNode(column_index[i]));
-                td_value.appendChild(document.createTextNode(value));
+                td_col = self.createElements(column_index[i], td_col);
+                td_value = self.createElements(value.replace('&lt;','<').replace('&gt;', '>') , td_value);
                 tr.appendChild(td_col);
                 tr.appendChild(td_value);
                 tbl.appendChild(tr);
@@ -256,8 +276,9 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
                   let td_col = document.createElement('td');
                   let td_value = document.createElement('td');
                   
-                  td_col.appendChild(document.createTextNode(i));
-                  td_value.appendChild(document.createTextNode(value));
+                  td_col = self.createElements(i, td_col);
+                  td_value = self.createElements(value.replace(/&lt;/g, '<').replace(/&gt;/g, '>'), td_value);
+
                   tr.appendChild(td_col);
                   tr.appendChild(td_value);
                   tbl.appendChild(tr);
@@ -294,7 +315,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
                     }
                   }
                   label.appendChild(input);
-                  label.appendChild(document.createTextNode(" "+value));
+                  label = self.createElements(" "+value.replace('&lt;','<').replace('&gt;', '>'), label)
                   btn_group.appendChild(label);
                 }
               })
